<?php

namespace App\Http\Controllers;

use App\Models\Company;
use Illuminate\Http\Request;
use App\Models\Transaction;
use Illuminate\Support\Facades\Crypt;
use Illuminate\Contracts\Encryption\DecryptException;

class TransactionController extends Controller
{
    public function index()
    {
        $data['title'] = 'E-Cash - Transactions';
        $data['transaction'] = Transaction::orderBy('date', 'asc')->get();
        $data['ic'] = Transaction::where('status', 1)->sum('amount');
        $data['oc'] = Transaction::where('status', 2)->sum('amount');
        $data['balance'] = Transaction::first();
        return view('transaction.index')->with($data);
    }

    public function store(Request $request)
    {
        $namaPerusahaan = Company::first()->nama;
        $request->validate([
            'desc' => 'required',
            'date' => 'required',
            'amount' => 'required',
            'status' => 'required',
            'sumber' => $request->status == '2' ? 'nullable' : 'required'
        ]);
        $data = [
            'sumber' => $request->status == '2' ? $namaPerusahaan : $request->sumber,
            'date' => $request->date,
            'description' => $request->desc,
            'amount' => $request->amount,
            'status' => $request->status,
            'kode_rekening' => $request->kode_rekening
        ];
        Transaction::create($data);
        return redirect()->route('transaction.index')->with('success', 'Data successfully added');
    }

    public function update(Request $request, string $id)
    {
        try {
            $namaPerusahaan = Company::first()->nama;
            $decryptedId = Crypt::decryptString($id);
            $request->validate([
                'date' => 'required',
                'desc' => 'required',
                'amount' => 'required',
                'status' => 'required',
            ]);
            $data = [
                'date' => $request->date,
                'description' => $request->desc,
                'amount' => $request->amount,
                'status' => $request->status,
                'sumber' => $request->sumber ? $request->sumber : $namaPerusahaan,
                'kode_rekening' => $request->kode_rekening
            ];
            Transaction::where('id', $decryptedId)->update($data);
            return redirect()->route('transaction.index')->with('success', 'Data successfully changed');
        } catch (DecryptException $e) {
            return redirect()->back()->with('error', 'Invalid ID');
        }
    }

    public function destroy(string $id)
    {
        try {
            $decryptedId = Crypt::decryptString($id);
            Transaction::where('id', $decryptedId)->delete();
            return redirect()->route('transaction.index')->with('success', 'Data successfully deleted');
        } catch (DecryptException $e) {
            return redirect()->back()->with('error', 'Invalid ID');
        }
    }

    public function cetak(string $id)
    {
        $decryptID = Crypt::decryptString($id);
        $data = Transaction::where('id', $decryptID)->first();
        $namaperusahaan = Company::first()->nama;
        $terbilang = Transaction::terbilang($data->amount);

        return view('transaction.cetak', [
            'data' => $data,
            'namaPerusahaan' => $namaperusahaan,
            'title' => 'Cetak Transaksi',
            'terbilang' => $terbilang,
            'tanggal' => Transaction::tanggalSekarang()
        ]);
    }
}
