@extends('template')

@section('content')
    <div class="page-info">
        <nav aria-label="breadcrumb">
            <ol class="breadcrumb">
                <li class="breadcrumb-item"><a href="#">Apps</a></li>
                <li class="breadcrumb-item active" aria-current="page">Users</li>
            </ol>
        </nav>
    </div>
    @include('message')
    <div class="main-wrapper">
        <div class="card">
            <div class="card-body">
                <a href="#" class="btn btn-primary rounded-pill btn-sm mb-4" data-toggle="modal"
                    data-target="#modalAdd"><i class="material-icons">add</i>Add</a>
                <a href="{{ route('printu') }}" class="btn btn-secondary rounded-pill btn-sm mb-4"><i
                        class="material-icons">print</i> Print</a>
                <div class="table-responsive">
                    <table class="table table-hover table-sm table-bordered" id="zero-conf">
                        <thead class="thead-dark">
                            <tr>
                                <th style="width: 10%" class="text-center">#</th>
                                <th>Photo</th>
                                <th>Name</th>
                                <th>Email</th>
                                <th>Level</th>
                                <th>Action</th>
                            </tr>
                        </thead>
                        <tbody>
                            @php
                                $no = 1;
                            @endphp
                            @foreach ($users as $item)
                                <tr>
                                    <td class="text-center">{{ $no++ }}</td>
                                    <td>
                                        @if ($item->photo != '')
                                            <img src="{{ asset('images') . '/' . $item->photo }}" alt="profile image"
                                                style="width: 150px" class="rounded-pill">
                                        @else
                                            <img src="{{ asset('images/default.png') }}" alt="profile image"
                                                style="width: 150px" class="rounded-pill">
                                        @endif
                                    </td>
                                    <td>{{ $item->name }}</td>
                                    <td>{{ $item->email }}</td>
                                    <td>{{ $item->level == 1 ? 'Bendahara' : 'Direktur' }}</td>
                                    <td style="width: 25%">
                                        <a href="#modalEdit" id="edit" data-toggle="modal" data-target="#modalEdit"
                                            class="btn btn-warning btn-sm rounded-pill" data-id="{{ $item->id }}"
                                            data-name="{{ $item->name }}" data-email="{{ $item->email }}"
                                            data-level="{{ $item->level }}" data-photo="{{ $item->photo }}"
                                            onclick="$('#modalEdit #formEdit').attr('action', '{{ route('users.update', Crypt::encryptString($item->id)) }}')"><i
                                                class="material-icons-outlined">edit</i>Edit</a>
                                        <a href="#modalDelete" data-toggle="modal" data-target="#modalDelete"
                                            class="btn btn-danger btn-sm rounded-pill"
                                            onclick="$('#modalDelete #formDelete').attr('action', '{{ route('users.destroy', Crypt::encryptString($item->id)) }}')"><i
                                                class="material-icons-outlined">delete</i>Delete</a>
                                    </td>
                                </tr>
                            @endforeach
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
    </div>

    {{-- Modal Add --}}
    <div class="modal fade" id="modalAdd" tabindex="-1" role="dialog" aria-labelledby="modalAddLabel" Add Users="true">
        <div class="modal-dialog" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="modalAddLabel">Add User</h5>
                    <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                        <i class="material-icons">close</i>
                    </button>
                </div>
                <form action="{{ route('users.store') }}" method="post" enctype="multipart/form-data">
                    <div class="modal-body">
                        @csrf
                        <div class="form-group">
                            <label for="name">Name</label>
                            <input type="text" name="name" class="form-control" id="name" placeholder="Name"
                                required>
                        </div>
                        <div class="form-group">
                            <label for="email">Email</label>
                            <input type="email" name="email" class="form-control" id="email"
                                placeholder="Email Address" required>
                        </div>
                        <div class="form-group">
                            <label for="password">Password</label>
                            <input type="password" name="password" class="form-control" placeholder="Password" required>
                        </div>
                        <div class="form-group">
                            <label for="level">Level</label>
                            <select name="level" id="level" class="form-control custom-select" required>
                                <option value="">- Choose -</option>
                                <option value="1">Bendahara</option>
                                <option value="2">Direktur</option>
                            </select>
                        </div>
                        <div class="form-group">
                            <label for="photo">photo</label>
                            <input type="file" name="photo" class="form-control" id="photo">
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-secondary" data-dismiss="modal">Close</button>
                        <button type="submit" class="btn btn-primary">Submit</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    {{-- Modal Update --}}
    <div class="modal fade" id="modalEdit" tabindex="-1" role="dialog" aria-labelledby="modalEditLabel" Add
        Users="true">
        <div class="modal-dialog" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="modalEditLabel">Edit User</h5>
                    <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                        <i class="material-icons">close</i>
                    </button>
                </div>
                <form action="" method="post" id="formEdit" enctype="multipart/form-data">
                    <div class="modal-body">
                        @csrf
                        @method('put')
                        <div class="form-group profile-img">
                            <center>
                                <img src="" alt="photo" id="photo" style="width: 150px"
                                    class="rounded-pill"><br>
                            </center>
                            <label for="photo">photo</label>
                            <input type="file" name="photo" class="form-control" id="photo">
                        </div>
                        <div class="form-group">
                            <label for="name">Name</label>
                            <input type="text" name="name" class="form-control" id="name" placeholder="Name"
                                required>
                        </div>
                        <div class="form-group">
                            <label for="email">Email</label>
                            <input type="email" name="email" class="form-control" id="email"
                                placeholder="Email Address" required>
                        </div>
                        <div class="form-group">
                            <label for="password">Password</label>
                            <input type="password" name="password" class="form-control" placeholder="Password">
                            <small class="text-info">*Leave blank if you don't want to change it*</small>
                        </div>
                        <div class="form-group">
                            <label for="level">Level</label>
                            <select name="level" id="level" class="form-control custom-select" required>
                                <option value="">- Choose -</option>
                                <option value="1">Bendahara</option>
                                <option value="2">Direktur</option>
                            </select>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-secondary" data-dismiss="modal">Close</button>
                        <button type="submit" class="btn btn-primary">Submit</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    {{-- Modal Delete --}}
    <div class="modal fade" id="modalDelete" tabindex="-1" role="dialog" aria-labelledby="modalDeleteLabel" Add
        Users="true">
        <div class="modal-dialog" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="modalDeleteLabel">Delete User</h5>
                    <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                        <i class="material-icons">close</i>
                    </button>
                </div>
                <form action="" method="post" id="formDelete">
                    <div class="modal-body">
                        @csrf
                        @method('delete')
                        <p>Sure you want to delete user</p>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-secondary" data-dismiss="modal">Close</button>
                        <button type="submit" class="btn btn-primary" autofocus>Yes</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <script>
        $(document).on('click', '#edit', function() {
            let name = $(this).data('name')
            let email = $(this).data('email')
            let lvl = $(this).data('level')
            let photo = $(this).data('photo')

            $('#modalEdit #name').val(name)
            $('#modalEdit #email').val(email)
            $('#modalEdit #level option').each(function() {
                if ($(this).val() == lvl) {
                    $(this).prop('selected', true);
                }
            });
            if (photo != '') {
                $('#modalEdit #photo').attr('src', "{{ asset('images') }}/" + photo)
            } else {
                $('#modalEdit #photo').attr('src', "{{ asset('images/default.png') }}")
            }
        })
    </script>
@endsection
